pub fn mondrian(n_trees: usize) -> MondrianForestExpand description
Create a Mondrian forest with the given number of trees.
use irithyll::{mondrian, StreamingLearner};
let mut model = mondrian(10);
model.train(&[1.0, 2.0], 3.0);pub fn mondrian(n_trees: usize) -> MondrianForestCreate a Mondrian forest with the given number of trees.
use irithyll::{mondrian, StreamingLearner};
let mut model = mondrian(10);
model.train(&[1.0, 2.0], 3.0);