pub fn quantize_weights_with_seed(weights: &[f64], seed: u64) -> TurboQuantizedExpand description
Quantize with an explicit seed for the Hadamard rotation (3.5-bit mode).
Backwards-compatible wrapper around quantize.
pub fn quantize_weights_with_seed(weights: &[f64], seed: u64) -> TurboQuantizedQuantize with an explicit seed for the Hadamard rotation (3.5-bit mode).
Backwards-compatible wrapper around quantize.